@@ -169,8 +169,11 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 /* UIN is digital according to the unofficial specification:
  * http://iserverd.khstu.ru/docum_ext/icqv5.html#CTS
- * 5 digits minimun according to http://en.wikipedia.org/wiki/ICQ#UIN */
-#define ICQ_USER_NAME     "(["DIGIT"]{5,})"
+ * 5 digits minimum according to http://en.wikipedia.org/wiki/ICQ#UIN
+ * According to an user, we can also provide an email address instead of the
+ * ICQ UIN. */
+#define ICQ_USER_NAME     "((["DIGIT"]{5,})|"EMAIL_LOCALPART"@"HOST")"
+
 /* Based on http://www.ietf.org/rfc/rfc2812.txt (section 2.3.1) */
 #define IRC_SPECIAL       "_\\[\\]{}\\\\|`^"
 #define IRC_USER_NAME     "(["ALPHA IRC_SPECIAL"]["ALPHADIGITDASH IRC_SPECIAL"]*)"
@@ -923,8 +926,10 @@ account_widget_applied_cb (GObject *source_object,
   EmpathyAccountSettings *settings = EMPATHY_ACCOUNT_SETTINGS (source_object);
   EmpathyAccountWidget *widget = EMPATHY_ACCOUNT_WIDGET (user_data);
   EmpathyAccountWidgetPriv *priv = GET_PRIV (widget);
+  gboolean reconnect_required;
 
-  empathy_account_settings_apply_finish (settings, res, &error);
+  empathy_account_settings_apply_finish (settings, res, &reconnect_required,
+      &error);
 
   if (error != NULL)
     {
@@ -961,10 +966,19 @@ account_widget_applied_cb (GObject *source_object,
                 GTK_TOGGLE_BUTTON (priv->enabled_checkbox));
 #endif /* HAVE_MEEGO */
 
-          if (tp_account_is_enabled (account) && enabled_checked)
+          /* If the account was offline, we always want to try reconnecting,
+           * to give it a chance to connect if the previous params were wrong.
+           * tp_account_reconnect_async() won't do anything if the requested
+           * presence is offline anyway. */
+          if (tp_account_get_connection_status (account, NULL) ==
+              TP_CONNECTION_STATUS_DISCONNECTED)
+            reconnect_required = TRUE;
+
+          if (reconnect_required && tp_account_is_enabled (account)
+              && enabled_checked)
             {
               /* After having applied changes to a user account, we
-               * automatically reconnect it. This is done so the new
+               * reconnect it if needed. This is done so the new
                * information entered by the user is validated on the server. */
               tp_account_reconnect_async (account, NULL, NULL);
             }
@@ -1089,7 +1103,8 @@ account_widget_launch_external_clicked (GtkWidget *button,
       /* we know how to handle this external provider */
       GDesktopAppInfo *desktop_info;
       GError *error = NULL;
-      GdkAppLaunchContext *context;
+      GdkAppLaunchContext *context = NULL;
+      GdkDisplay *display;
       gchar *cmd;
       GAppInfo *app_info;
 
@@ -1114,9 +1129,8 @@ account_widget_launch_external_clicked (GtkWidget *button,
           goto out;
         }
 
-      context = gdk_app_launch_context_new ();
-      gdk_app_launch_context_set_screen  (context,
-          gtk_widget_get_screen (button));
+      display = gdk_display_get_default ();
+      context = gdk_display_get_app_launch_context (display);
 
       if (!g_app_info_launch (app_info, NULL, (GAppLaunchContext *) context,
             &error))
@@ -1683,7 +1697,6 @@ account_widget_build_yahoo (EmpathyAccountWidget *self,
       empathy_account_widget_handle_params (self,
           "entry_id", "account",
           "entry_password", "password",
-          "entry_server", "server",
           "entry_locale", "room-list-locale",
           "entry_charset", "charset",
           "spinbutton_port", "port",
@@ -1988,6 +2001,8 @@ add_enable_checkbox (EmpathyAccountWidget *self,
   gtk_widget_show (w);
 #else
   priv->enabled_checkbox =
+      /* translators: this is the label of a checkbox used to enable/disable IM
+       * accounts */
       gtk_check_button_new_with_mnemonic (_("_Enabled"));
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->enabled_checkbox),
