@@ -244,6 +244,7 @@ empathy_contact_block_menu_item_toggled (GtkCheckMenuItem *item,
 	if (blocked) {
 		/* confirm the user really wishes to block the contact */
 		GtkWidget *parent;
+		GdkPixbuf *avatar;
 
 		/* gtk_menu_get_attach_widget () doesn't behave properly here
 		 * for some reason */
@@ -251,8 +252,10 @@ empathy_contact_block_menu_item_toggled (GtkCheckMenuItem *item,
 			G_OBJECT (gtk_widget_get_parent (GTK_WIDGET (item))),
 			"window");
 
+		avatar = empathy_pixbuf_avatar_from_contact_scaled (contact, 48, 48);
+
 		if (!empathy_block_contact_dialog_show (GTK_WINDOW (parent),
-					contact, &abusive))
+					contact, avatar, &abusive))
 			return;
 	}
 
@@ -311,7 +314,7 @@ static void
 empathy_contact_chat_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-  empathy_chat_with_contact (contact, gtk_get_current_event_time ());
+	empathy_chat_with_contact (contact, empathy_get_current_action_time ());
 }
 
 GtkWidget *
@@ -340,9 +343,8 @@ static void
 empathy_contact_audio_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-
 	empathy_call_new_with_streams (contact, TRUE, FALSE,
-		gtk_get_current_event_time ());
+		empathy_get_current_action_time ());
 }
 
 GtkWidget *
@@ -373,7 +375,7 @@ empathy_contact_video_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
 	empathy_call_new_with_streams (contact, TRUE, TRUE,
-		gtk_get_current_event_time ());
+		empathy_get_current_action_time ());
 }
 
 GtkWidget *
