@@ -22,8 +22,9 @@
  *     Danielle Madeley <danielle.madeley@collabora.co.uk>
  *     Emilio Pozuelo Monfort <emilio.pozuelo@collabora.co.uk>
  */
+#include "config.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <telepathy-glib/telepathy-glib.h>
 
@@ -32,6 +33,9 @@
 
 #include <libempathy-gtk/empathy-account-chooser.h>
 #include <libempathy-gtk/empathy-cell-renderer-text.h>
+#include <libempathy-gtk/empathy-cell-renderer-activatable.h>
+#include <libempathy-gtk/empathy-contact-dialogs.h>
+#include <libempathy-gtk/empathy-images.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
@@ -104,7 +108,11 @@ on_searcher_reset (GObject *source_object,
   search = g_hash_table_new (g_str_hash, g_str_equal);
 
   search_criteria = gtk_entry_get_text (GTK_ENTRY (priv->search_entry));
-  g_hash_table_insert (search, "fn", (gpointer) search_criteria);
+
+  if (tp_strv_contains (tp_contact_search_get_search_keys (searcher), ""))
+    g_hash_table_insert (search, "", (gpointer) search_criteria);
+  else
+    g_hash_table_insert (search, "fn", (gpointer) search_criteria);
 
   gtk_list_store_clear (priv->store);
   tp_contact_search_start (priv->searcher, search);
@@ -165,6 +173,9 @@ add_selected_contact (EmpathyContactSearchDialog *self)
   empathy_tp_contact_factory_get_from_id (conn, id,
       on_get_contact_factory_get_from_id_cb, NULL,
       NULL, NULL);
+
+  /* Close the dialog */
+  gtk_dialog_response (GTK_DIALOG (self), GTK_RESPONSE_CANCEL);
 }
 
 static void
@@ -344,7 +355,7 @@ _account_chooser_changed (EmpathyAccountChooser *chooser,
 }
 
 static void
-_on_button_search_clicked (GtkButton *button,
+_on_button_search_clicked (GtkWidget *widget,
     EmpathyContactSearchDialog *self)
 {
   empathy_contact_search_dialog_do_search (self);
@@ -380,12 +391,14 @@ supports_contact_search_cb (GObject *conn,
     gpointer user_data)
 {
   FilterCallbackData *data = user_data;
-  GError *myerr = NULL;
+  GError *error = NULL;
   TpCapabilities *caps;
 
-  if (!tp_proxy_prepare_finish (conn, result, &myerr))
+  if (!tp_proxy_prepare_finish (conn, result, &error))
     {
+      DEBUG ("Error preparing the connection: %s", error->message);
       data->callback (FALSE, data->user_data);
+      g_error_free (error);
       g_slice_free (FilterCallbackData, data);
       return;
     }
@@ -431,6 +444,61 @@ empathy_account_chooser_filter_supports_contact_search (
       cb_data);
 }
 
+static void
+contact_search_dialog_row_activated_cb (GtkTreeView *tv,
+    GtkTreePath *path,
+    GtkTreeViewColumn *column,
+    EmpathyContactSearchDialog *self)
+{
+  /* just emit the same response as the Add Button */
+  gtk_dialog_response (GTK_DIALOG (self), GTK_RESPONSE_APPLY);
+}
+
+static void
+on_profile_button_got_contact_cb (TpConnection *connection,
+    EmpathyContact *contact,
+    const GError *error,
+    gpointer user_data,
+    GObject *object)
+{
+ if (error != NULL)
+   {
+     g_warning ("Error while getting the contact: %s", error->message);
+     return;
+   }
+
+  empathy_contact_information_dialog_show (contact, NULL);
+}
+
+static void
+on_profile_button_clicked_cb (EmpathyCellRendererActivatable *cell,
+    const gchar *path_string,
+    EmpathyContactSearchDialog *self)
+{
+  EmpathyContactSearchDialogPrivate *priv = GET_PRIVATE (self);
+  TpConnection *conn;
+  GtkTreeIter iter;
+  GtkTreeModel *model;
+  gboolean valid;
+  gchar *id;
+
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree_view));
+
+  conn = empathy_account_chooser_get_connection (
+      EMPATHY_ACCOUNT_CHOOSER (priv->chooser));
+
+  valid = gtk_tree_model_get_iter_from_string (model, &iter, path_string);
+  g_return_if_fail (valid == TRUE);
+
+  gtk_tree_model_get (model, &iter, LOGIN_COLUMN, &id, -1);
+
+  DEBUG ("Requested to show profile for contact: %s", id);
+
+  empathy_tp_contact_factory_get_from_id (conn, id,
+      on_profile_button_got_contact_cb, NULL,
+      NULL, NULL);
+}
+
 static void
 empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
 {
@@ -439,26 +507,29 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   GtkCellRenderer *cell;
   GtkTreeViewColumn *col;
   GtkTreeSelection *selection;
+  GtkSizeGroup *size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
   gchar *tmp;
 
   /* Title */
   gtk_window_set_title (GTK_WINDOW (self), _("Search contacts"));
 
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_vbox_new (FALSE, 3);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 
   /* Account chooser */
   hbox = gtk_hbox_new (FALSE, 6);
   label = gtk_label_new (_("Account:"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
+  gtk_size_group_add_widget (size_group, label);
 
   priv->chooser = empathy_account_chooser_new ();
   empathy_account_chooser_set_filter (EMPATHY_ACCOUNT_CHOOSER (priv->chooser),
       empathy_account_chooser_filter_supports_contact_search, NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->chooser, FALSE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (hbox), priv->chooser, TRUE, TRUE, 0);
   g_signal_connect (priv->chooser, "changed",
       G_CALLBACK (_account_chooser_changed), self);
 
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
 
 #if 0
   /* Server entry */
@@ -471,18 +542,22 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   /* Search input */
   hbox = gtk_hbox_new (FALSE, 6);
   label = gtk_label_new (_("Search: "));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
+  gtk_size_group_add_widget (size_group, label);
 
   priv->search_entry = gtk_entry_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), priv->search_entry, TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (hbox), priv->search_entry, TRUE, TRUE, 0);
+  g_signal_connect (priv->search_entry, "activate",
+      G_CALLBACK (_on_button_search_clicked), self);
 
   priv->find_button = gtk_button_new_from_stock (GTK_STOCK_FIND);
-  g_signal_connect (priv->find_button, "clicked", G_CALLBACK (_on_button_search_clicked), self);
-  gtk_box_pack_end (GTK_BOX (hbox), priv->find_button, FALSE, TRUE, 6);
+  g_signal_connect (priv->find_button, "clicked",
+      G_CALLBACK (_on_button_search_clicked), self);
+  gtk_box_pack_end (GTK_BOX (hbox), priv->find_button, FALSE, TRUE, 0);
 
   priv->spinner = gtk_spinner_new ();
-  gtk_box_pack_end (GTK_BOX (hbox), priv->spinner, FALSE, TRUE, 6);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 6);
+  gtk_box_pack_end (GTK_BOX (hbox), priv->spinner, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
 
   /* Search results */
   priv->store = gtk_list_store_new (N_COLUMNS,
@@ -493,12 +568,15 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->tree_view));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
+  g_signal_connect (priv->tree_view, "row-activated",
+      G_CALLBACK (contact_search_dialog_row_activated_cb), self);
   g_signal_connect (selection, "changed",
       G_CALLBACK (on_selection_changed), self);
 
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (priv->tree_view), FALSE);
 
   col = gtk_tree_view_column_new ();
+
   cell = empathy_cell_renderer_text_new ();
   gtk_tree_view_column_pack_start (col, cell, TRUE);
   /* EmpathyCellRendererText displays "name" above and "status" below.
@@ -509,14 +587,22 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   gtk_tree_view_column_add_attribute (col, cell,
       "status", NAME_COLUMN);
 
+  cell = empathy_cell_renderer_activatable_new ();
+  gtk_tree_view_column_pack_end (col, cell, FALSE);
+  g_object_set (cell, "stock-id", EMPATHY_IMAGE_CONTACT_INFORMATION, NULL);
+  g_signal_connect (cell, "path-activated",
+      G_CALLBACK (on_profile_button_clicked_cb), self);
+
   gtk_tree_view_append_column (GTK_TREE_VIEW (priv->tree_view), col);
 
   gtk_dialog_add_button (GTK_DIALOG (self),
       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
   priv->add_button = gtk_dialog_add_button (GTK_DIALOG (self),
-      GTK_STOCK_ADD, GTK_RESPONSE_APPLY);
+      _("_Add Contact"), GTK_RESPONSE_APPLY);
   gtk_widget_set_sensitive (priv->add_button, FALSE);
+  gtk_button_set_image (GTK_BUTTON (priv->add_button),
+      gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON));
 
   /* Pack the dialog */
   priv->notebook = gtk_notebook_new ();
@@ -538,16 +624,15 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   gtk_label_set_ellipsize (GTK_LABEL (priv->no_contact_found),
       PANGO_ELLIPSIZE_END);
 
-
   gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), scrolled_window,
       NULL);
   gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook),
       priv->no_contact_found, NULL);
 
-  gtk_box_pack_start (GTK_BOX (vbox), priv->notebook, TRUE, TRUE, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->notebook, TRUE, TRUE, 3);
 
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (
-          GTK_DIALOG (self))), vbox, TRUE, TRUE, 6);
+          GTK_DIALOG (self))), vbox, TRUE, TRUE, 0);
 
   gtk_window_set_default_size (GTK_WINDOW (self), 200, 400);
   gtk_widget_show_all (vbox);
