@@ -220,6 +220,8 @@ main_window_flash_foreach (GtkTreeModel *model,
 		pixbuf = empathy_individual_store_get_individual_status_icon (
 						GET_PRIV (data->window)->individual_store,
 						individual);
+		if (pixbuf != NULL)
+			g_object_ref (pixbuf);
 	}
 
 	gtk_tree_store_set (GTK_TREE_STORE (model), iter,
@@ -240,6 +242,7 @@ main_window_flash_foreach (GtkTreeModel *model,
 
 	g_object_unref (individual);
 	tp_clear_object (&contact);
+	tp_clear_object (&pixbuf);
 
 	return FALSE;
 }
@@ -1250,7 +1253,7 @@ main_window_favorite_chatroom_join (EmpathyChatroom *chatroom)
 		join_fav_account_sig_ctx *ctx;
 
 		ctx = join_fav_account_sig_ctx_new (account, chatroom,
-			gtk_get_current_event_time ());
+			empathy_get_current_action_time ());
 
 		ctx->sig_id = g_signal_connect_data (account, "status-changed",
 			G_CALLBACK (account_status_changed_cb), ctx,
@@ -1261,7 +1264,7 @@ main_window_favorite_chatroom_join (EmpathyChatroom *chatroom)
 		return;
 	}
 
-	join_chatroom (chatroom, gtk_get_current_event_time ());
+	join_chatroom (chatroom, empathy_get_current_action_time ());
 }
 
 static void
